@@ -1,4 +1,4 @@
-from .utils import urlfor
+from .utils import urlforversion
 
 __all__ = ['JobRunnerMixin']
 
@@ -116,7 +116,7 @@ class JobRunnerMixin(object):
 
         data.update(extra_query)
 
-        endpoint = urlfor('jobs', 'search')
+        endpoint = urlforversion(self.api_version, 'jobs', 'search')
         resp = self._make_request('GET', endpoint, params=data)
         self._check_response(resp)
         return resp.json()
@@ -130,7 +130,7 @@ class JobRunnerMixin(object):
 
         data.update(extra_query)
 
-        endpoint = urlfor('jobs', 'results')
+        endpoint = urlforversion(self.api_version, 'jobs', 'results')
         resp = self._make_request('GET', endpoint, params=data)
         self._check_response(resp)
         return resp.json()
@@ -206,7 +206,9 @@ class JobRunnerMixin(object):
         return ResultIter(self.raw_results, job_id, **kwargs)
 
     def jobs_create(self, input, from_url=False, filename=None,
-                    auto_parse=False, auto_start=False, as_sample=False):
+                    auto_parse=False, auto_start=False, as_sample=False,
+                    historical_data=True, allow_manual_review=None,
+                    callback_url=None, callback_headers=None):
         """
         Creates a bulk job.
 
@@ -237,6 +239,22 @@ class JobRunnerMixin(object):
                 If ``True``, run only a sample of the given input and return an
                 estimation of the job's total bounce rate.
 
+            historical_data (bool): If ``True``, return historical data.
+                Default is ``True``.
+
+            allow_manual_review (bool):
+                If ``True``, allows job to fall to manual review.
+                Default is ``None``.
+
+            callback_url (str):
+                If given, callbacks will be send to the specified URL. Default
+                is ``None``.
+
+            callback_headers (dict):
+                If given, callbacks with headers will be send to the URL
+                specified in "callback_url".
+                Default is ``None``.
+
         Returns:
             A ``dict`` with keys ``status``, ``job_id``, and
             ``execution_time``.
@@ -244,23 +262,36 @@ class JobRunnerMixin(object):
         See Also:
             https://developers.neverbounce.com/v4.0/reference#jobs-create
         """
-        endpoint = urlfor('jobs', 'create')
+        endpoint = urlforversion(self.api_version, 'jobs', 'create')
 
         data = dict(input=input,
                     auto_parse=int(auto_parse),
                     auto_start=int(auto_start),
-                    as_sample=int(as_sample))
+                    run_sample=int(as_sample))
+
+        data['request_meta_data'] = {
+            'leverage_historical_data': int(historical_data)
+        }
 
         data['input_location'] = 'remote_url' if from_url else 'supplied'
         if filename is not None:
             data['filename'] = filename
 
+        if allow_manual_review is not None:
+            data['allow_manual_review'] = int(allow_manual_review)
+
+        if callback_url is not None:
+            data['callback_url'] = callback_url
+
+        if callback_headers is not None:
+            data['callback_headers'] = callback_headers
+
         resp = self._make_request('POST', endpoint, json=data)
         self._check_response(resp)
 
         return resp.json()
 
-    def jobs_parse(self, job_id, auto_start=True):
+    def jobs_parse(self, job_id, auto_start=False):
         """
         This endpoint allows you to parse a job created with auto_parse
         disabled. You cannot reparse a list once it's been parsed.
@@ -280,13 +311,13 @@ class JobRunnerMixin(object):
         See Also:
             https://developers.neverbounce.com/v4.0/reference#jobs-parse
         """
-        endpoint = urlfor('jobs', 'parse')
+        endpoint = urlforversion(self.api_version, 'jobs', 'parse')
         data = dict(job_id=job_id, auto_start=int(auto_start))
         resp = self._make_request('POST', endpoint, json=data)
         self._check_response(resp)
         return resp.json()
 
-    def jobs_start(self, job_id, run_sample=False):
+    def jobs_start(self, job_id, run_sample=False, allow_manual_review=None):
         """
         This endpoint allows you to start a job created or parsed with
         auto_start disabled. Once the list has been started the credits will be
@@ -300,6 +331,10 @@ class JobRunnerMixin(object):
                 Whether or not to run a sample of this job's contents and
                 return an estimate of the job's bounce rate
 
+            allow_manual_review (bool):
+                If ``True``, allows job to fall to manual review.
+                Default is ``None``.
+
         Returns:
             A ``dict`` with keys ``status``, ``queue_id``, and
             ``execution_time``.
@@ -307,8 +342,12 @@ class JobRunnerMixin(object):
         See Also:
             https://developers.neverbounce.com/v4.0/reference#jobs-start
         """
-        endpoint = urlfor('jobs', 'start')
+        endpoint = urlforversion(self.api_version, 'jobs', 'start')
         data = dict(job_id=job_id, run_sample=int(run_sample))
+
+        if allow_manual_review is not None:
+            data['allow_manual_review'] = int(allow_manual_review)
+
         resp = self._make_request('POST', endpoint, json=data)
         self._check_response(resp)
         return resp.json()
@@ -328,7 +367,7 @@ class JobRunnerMixin(object):
         See also:
             https://developers.neverbounce.com/v4.0/reference#jobs-status
         """
-        endpoint = urlfor('jobs', 'status')
+        endpoint = urlforversion(self.api_version, 'jobs', 'status')
         resp = self._make_request('GET', endpoint, params=dict(job_id=job_id))
         self._check_response(resp)
         return resp.json()
@@ -476,7 +515,7 @@ class JobRunnerMixin(object):
             'spooled': 'LINEFEED_0A'       # \n\r
         })
 
-        endpoint = urlfor('jobs', 'download')
+        endpoint = urlforversion(self.api_version, 'jobs', 'download')
         # the return val is (possibly) streaming; remember to set stream
         resp = self._make_request('POST', endpoint, json=data, stream=True)
 
@@ -501,7 +540,7 @@ class JobRunnerMixin(object):
         See Also:
             https://developers.neverbounce.com/v4.0/reference#jobs-delete
         """
-        endpoint = urlfor('jobs', 'delete')
+        endpoint = urlforversion(self.api_version, 'jobs', 'delete')
         resp = self._make_request('GET', endpoint, params=dict(job_id=job_id))
         self._check_response(resp)
         return resp.json()
