@@ -4,7 +4,7 @@ Tests the Accounts endpoints
 import responses
 
 import neverbounce_sdk
-from neverbounce_sdk import urlfor
+from neverbounce_sdk import urlforversion
 
 
 @responses.activate
@@ -14,7 +14,7 @@ def test_account_info():
 
     # this is the exepcted response
     responses.add(responses.GET,
-                  urlfor('account', 'info'),
+                  urlforversion('v4.2', 'account', 'info'),
                   status=200,
                   json={'status': 'success'})
 
@@ -22,4 +22,4 @@ def test_account_info():
     assert info == {'status': 'success'}
     assert len(responses.calls) == 1
     assert (responses.calls[0].request.url ==
-            'https://api.neverbounce.com/v4/account/info?key=static+key')
+            'https://api.neverbounce.com/v4.2/account/info?key=static+key')
